@@ -1,4 +1,6 @@
-use crate::{CryptoError, Entry, IndexedStorer, IndexedTypeStorer, StorableType, Storer};
+use crate::{
+    CryptoError, Entry, IndexedStorer, IndexedTypeStorer, StorableType, Storer, TypeStorer,
+};
 use async_trait::async_trait;
 use futures::StreamExt;
 use mongodb::{
@@ -75,6 +77,12 @@ impl From<MongoStorer> for IndexedTypeStorer {
     }
 }
 
+impl From<MongoStorer> for TypeStorer {
+    fn from(ms: MongoStorer) -> Self {
+        TypeStorer::Indexed(IndexedTypeStorer::Mongo(ms))
+    }
+}
+
 impl MongoStorer {
     /// Instantiates a mongo-backed key storer using a URL to the mongo cluster and the
     /// name of the DB to connect to.
